@@ -10,7 +10,7 @@ import singer.schema
 from singer import utils, metadata, get_bookmark
 from singer.schema import Schema
 from singer.catalog import Catalog, CatalogEntry
-from c8connector import C8Connector, ConfigProperty, Sample, SchemaAttribute, SchemaAttributeType
+from c8connector import C8Connector, ConfigProperty, Sample, SchemaAttribute, SchemaAttributeType, ConfigAttributeType
 import c8_source_oracle.db as orc_db
 import c8_source_oracle.sync_strategies.log_miner as log_miner
 import c8_source_oracle.sync_strategies.full_table as full_table
@@ -624,38 +624,38 @@ class OracleSourceConnector(C8Connector):
    def config(self) -> list[ConfigProperty]:
       """Get configuration parameters for the connector."""
       return [
-         ConfigProperty('host', 'string', True, False,
-                        description="Oracle DB host",
-                        example="58.13.14.19"),
-         ConfigProperty('port', 'integer', True, False,
-                        description="Oracle DB port",
-                        example="1521"),
-         ConfigProperty('user', 'string', True, False,
-                        description="Oracle DB username",
-                        example="macrometa"),
-         ConfigProperty('password', 'string', True, False,
-                        description="Oracle DB user's password",
-                        example="oracle"),
-         ConfigProperty('default_replication_method', 'string', True, False,
-                        description="Default replication method to use when no one is provided in the "
-                                    "catalog (Values: LOG_BASED, INCREMENTAL or FULL_TABLE).",
-                        example="LOG_BASED"),
-         ConfigProperty('filter_schemas', 'string', False, False,
-                        description="Scan only the specified comma-separated schemas to improve the "
-                                    "performance of data extraction",
-                        example="C##CUSTOMERS"),
-         ConfigProperty('service_name', 'string', True, False,
-                        description="Oracle DB service name",
-                        example="ORCLCDB"),
-         ConfigProperty('pdb_name', 'string', False, False,
-                        description="Oracle portable db name",
-                        example="ORCLPDB1"),
-         ConfigProperty('multitenant', 'boolean', False, False,
-                        description="Is Oracle DB is multi tennat or not",
-                        example="true"),
-         ConfigProperty('scn_window_size', 'integer', False, False,
-                        description="Oracle scn window for logminer replication",
-                        example="1000"),
+         ConfigProperty('host', ConfigAttributeType.STRING, True, False,
+                        description='Oracle DB host',
+                        example='58.13.14.19'),
+         ConfigProperty('port', ConfigAttributeType.INT, True, False,
+                        description='Oracle DB port',
+                        example='1521'),
+         ConfigProperty('user', ConfigAttributeType.STRING, True, False,
+                        description='Oracle DB username',
+                        example='macrometa'),
+         ConfigProperty('password', ConfigAttributeType.STRING, True, False,
+                        description='Oracle DB user password',
+                        example='oracle'),
+         ConfigProperty('default_replication_method', ConfigAttributeType.STRING, True, False,
+                        description='Default replication method to use when no one is provided in the '
+                                    'catalog (Values: LOG_BASED, INCREMENTAL or FULL_TABLE).',
+                        example='LOG_BASED'),
+         ConfigProperty('filter_schemas', ConfigAttributeType.STRING, False, False,
+                        description='Scan only the specified comma-separated schemas to improve the '
+                                    'performance of data extraction',
+                        example='C##CUSTOMERS'),
+         ConfigProperty('service_name', ConfigAttributeType.STRING, True, False,
+                        description='Oracle DB service name',
+                        example='ORCLCDB'),
+         ConfigProperty('pdb_name', ConfigAttributeType.STRING, False, False,
+                        description='Oracle portable db name',
+                        example='ORCLPDB1'),
+         ConfigProperty('multitenant', ConfigAttributeType.BOOLEAN, False, False,
+                        description='Is Oracle DB is multi tennat or not',
+                        example='true'),
+         ConfigProperty('scn_window_size', ConfigAttributeType.INT, False, False,
+                        description='Oracle scn window for logminer replication',
+                        example='1000'),
       ]
 
    def capabilities(self) -> list[str]:
